/*  PRIZM Controller example program
 *  This program implements line following using the Pixy2 Camera. The Pixy2 camera must be connected   
 *  to the I2C port on PRIZM. Pixy2 can be trained to follow thin lines that are drawn with a marker 
 *  or wide lines that can be created with vinyl tape. Using the PixyMon software, the camera can be 
 *  configured to look for certain width of lines.
 *  author ABL 02/24/2020
 */

  #include <PRIZM.h>                                // include PRIZM library
  #include <Pixy2I2C.h>                             // include Pixy2 library
  Pixy2I2C pixy;                                    // instantiate a name for Pixy2 object
  PRIZM prizm;                                      // instantiate a PRIZM object “prizm” so we can use its functions

  #define I2C                                       // define how the Pixy2 will communicate with PRIZM
  #define xCenter (pixy.frameWidth/2)               // declare a constant equal to half the frame width of the camera 
  
void setup() {

  prizm.PrizmBegin();                               // initialize PRIZM
  prizm.setMotorInvert(1,1);                        // invert the direction of DC Motor 1                               
  Serial.begin(9600);                               // start the serial monitor
  Serial.println("Starting...");                    // indicate that Pixy2 is starting up
  
  pixy.init();                                      // initialize the Pixy2 camera
  pixy.setLamp(1, 1);                               // turn on both Pixy2 lamps for maximum exposure
  pixy.changeProg("line");                          // change to the line_tracking program
}

void loop() {
  int8_t lines;                                     // create an 8-bit variable named lines
  lines = pixy.line.getMainFeatures();              // store all the main components of the detected lines
 
  if (lines<=0){                                    // if no lines were detected:
    prizm.setMotorPowers(125,125);                    // stop both motors
    Serial.println("Stop");                           // display "Stop" in the serial monitor
  }
  else if(pixy.line.vectors->m_x1 > xCenter){       // else if the vector end is to the right of center:
    prizm.setMotorPowers(30,125);                     // turn right
    Serial.println("Turn Right");                     // indicate direction in the serial monitor                                             
  }  
  else if(pixy.line.vectors->m_x1 < xCenter){       // else if the vector end is to the left of center:
    prizm.setMotorPowers(125,30);                     // turn left
    Serial.println("Turn Left");                      // indicate direction in the serial monitor 
  }
  else {                                            // else vector must be directly in the center:
    prizm.setMotorPowers(30,30);                      // go straight forward
    Serial.println("Forward");                        // indicate movement in the serial monitor 
  }
   
}
