/*  PRIZM Controller example program
 *  This program was specifically designed for the TaskBot but can be used with any differential drive robot.
 *  
 *  This program implements object recognition using the Pixy2 Camera. The Pixy2 camera must be connected   
 *  to the I2C port on PRIZM. Pixy2 can be trained to recoginize objects by their color using the PixyMon
 *  software. Once Pixy2 detects an object, it sends information about that object back to PRIZM which 
 *  can be used by the program to control the robot.
 *  
 *  author ABL 03/11/2020
 */

#include <PRIZM.h>      // include PRIZM library
#include <Pixy2I2C.h>   // include Pixy2 library
#define I2C
Pixy2I2C pixy;          // instantiate a name for Pixy2 class
PRIZM prizm;            // instantiate a name fo PRIZM class

int stopSign = 0;       // tracks the number of stop signs detected
int goSign = 0;         // tracks the number of go signs detected
int mPower = 0;         // stores the power of the motors

void setup()
{

  prizm.PrizmBegin();
  prizm.setMotorInvert(1,1);                          // invert DC motor channel 1 on the PRIZM controller

  Serial.begin(9600);                                 // start the serial monitor
  Serial.println("Starting...");                      // indicate that Pixy2 is starting up
      
  pixy.init();                                        // initialize the Pixy2 camera
  pixy.changeProg("color_connected_components");      // change to the color connected components mode

  delay(500);                                         // short delay on startup
}

void loop(){ 
  pixy.ccc.getBlocks();                               // grab blocks (signs) if any are available 

  if (pixy.ccc.numBlocks > 0){                        // if the camera detects one or more blocks (signs)
    Serial.print("Detected ");                          // print the number of signs detected
    Serial.print(pixy.ccc.numBlocks);
    Serial.println(" signs");
    Serial.println("");

    for (int i=0; i<pixy.ccc.numBlocks; i++){           // check each sign to see what it is
      pixy.ccc.blocks[i].print();                         // print the information for each sign
      Serial.println("");
      if (pixy.ccc.blocks[i].m_signature == 1){           // if the sign is a stop sign:
        stopSign = stopSign + 1;                            // add 1 to the number of stop signs detected
      }
      else if (pixy.ccc.blocks[i].m_signature == 4){      // if the sign is a go sign:
        goSign = goSign + 1;                                // add 1 to the number of go signs detected
      }                                                 
    }

    if (stopSign >= 1){                                 // if there are stop signs present:
      mPower = 125;                                       // set the mPower variable to stop the motors
    } 
    else if (goSign >= 1){                              // otherwise if there is a go sign present:
      mPower = 50;                                        // set the mPower variable to move the motors at 50%
    }
  }
  
  prizm.setMotorPowers(mPower,mPower);              // either move or stop the motors based on the mPower variable
  stopSign = 0;                                     // reset the number of stop signs detected
  goSign = 0;                                       // reset the number of go signs detected
}
