/*    demo example for using Pixy Cam with TETRIX PRIZM  for a
 *    2-motor drive robot that will follow a blue ball that is in camera view.
 *    Before running this sketch, your Pixy camera must first be trained to recognize objects using Pixy Monitor software.
 *    It will also need to be configured as I2C mode.
 *    You can download the Pixy Mon software and view lot's of tutorials and examples at the Pixycam webiste
 *    https://pixycam.com/
 *    You will also need the Pixy Cam to Grove connection adapter from TETRIX by Pitsco to be able to connect the Pixy2 camera module to PRIZM's I2C sensor port.
 *    https://www.pitsco.com/Shop/TETRIX-Robotics
 *    
 *    
 *    
 *    Motor Hookup: Camera facing forward on two motor drive rover bot
 *    PRIZM Controller: 
 *           Channel 1 is Left front wheel
 *           Channel 2 is Right front wheel
 *           
 *    It is recommended that the rear wheels be TETRIX Omni wheels so that rover can easily pivot when attempting to turn
 *    
 *    
 */

#include <PRIZM.h>      // include PRIZM library
#include <Pixy2I2C.h>   // include Pixy Cam I2C library
#define I2C

Pixy2I2C pixy;          // instantiate a name for pixy cam class
PRIZM prizm;            // instantiate a name fo PRIZM class


int centerX;            // location of object along the X coordinate of the camera frame
int centerY;            // location of object along the Y corrdinate of the camera frame

void setup()
{

  prizm.PrizmBegin();
  prizm.setMotorInvert(2,1);    // invert DC motor channel 2 on the PRIZM controller
      
  pixy.init();
  pixy.changeProg("color_connected_components");

  delay(500); // short delay on startup
}

void loop()
{ 
  
  pixy.ccc.getBlocks();          // grab blocks if any are available! (Detected objects that pixy cam has been trained to recognized are called blocks)
 
    if (pixy.ccc.numBlocks){     // if we detect a block
      
      centerX = pixy.ccc.blocks[0].m_x;  // the x location of the center of the object 
      centerY = pixy.ccc.blocks[0].m_y;  // the y location of the center of the object  
         
//    printData();              // uncomment if you want to view the centerX and centerY coordinate values of a detected object
      trackObject();            // if we see the ball in the camera frame, go track it
       
    } else {
    
      driveStop();              // if we lose the ball in the camera frame, or don't see it, stop the motors
      
    }
}


void trackObject(){
  
  int motorsY = map(centerY, 0, 208, -100, 100);    // map motors from position of object in pixy cam Y coordinate 0 - 208 to motor powers 100 to -100.
  int motorsX = map(centerX, 0, 316, 100, -100);    // map motors from position of object in pixy cam X coordinate 0 - 316 to motor powers -100 to 100.

  int Left   =  -motorsX + motorsY;    // mix channels
  int Right  =   motorsX + motorsY;    // mix channels

  constrain(Right, -100, 100);        // constrain values to not exceed -100 to 100 range
  constrain(Left,  -100, 100);

  prizm.setMotorPowers(Right,Left);   // Send power and direction to channel 1 and channel 2 PRIZM motor channels
    
}

void driveStop(){
  prizm.setMotorPowers(0,0);
}

void printData(){
   Serial.print (centerX);            // prints the centerX and centerY data values of a detected object to the serial monitor
   Serial.print ("  :  ");
   Serial.println (centerY);
  
}
