/*  This example sketch uses Pixy cam plugged into PRIZM I2C port.
 *  This sketch will read ALL line vector, intersection and barcode data
 *  and print to serial monitor
 * 
 *  The Pixy Cam needs to be configured for I2C communication
 *  and also be trained to recognize objects using the Pixy Mon Software.
 *  Information is here: https://pixycam.com/
 * 
 */
 
#include <PRIZM.h>      // include PRIZM library
#include <Pixy2I2C.h>   // include Pixy Cam I2C library
#define I2C

Pixy2I2C pixy;          // instantiate a name for pixy cam object
PRIZM prizm;            // instantiate a name for PRIZM object



void setup()
{
  prizm.PrizmBegin();   // initialize PRIZM. Wait for green start button press
   
  Serial.begin(9600);
  Serial.print("Starting...\n");

  // we need to initialize the pixy object
  pixy.init();
  // Change to line tracking program
  pixy.changeProg("line");
}

void loop()
{
  int8_t i;
  char buf[128];
 
  pixy.line.getAllFeatures();

  // print all vectors
  for (i=0; i<pixy.line.numVectors; i++)
  {
    sprintf(buf, "line %d: ", i);
    Serial.print(buf);
    pixy.line.vectors[i].print();
  }
  
  // print all intersections
  for (i=0; i<pixy.line.numIntersections; i++)
  {
    sprintf(buf, "intersection %d: ", i);
    Serial.print(buf);
    pixy.line.intersections[i].print();
  }
  
  // print all barcodes
  for (i=0; i<pixy.line.numBarcodes; i++)
  {
    sprintf(buf, "barcode %d: ", i);
    Serial.print(buf);
    pixy.line.barcodes[i].print();
  }
}
