/*  This example sketch uses Pixy cam plugged into PRIZM I2C port.
 *  This sketch will read line vector, intersection and barcode data
 *  and print to serial monitor
 * 
 *  The Pixy Cam needs to be configured for I2C communication
 *  and also be trained to recognize objects using the Pixy Mon Software.
 *  Information is here: https://pixycam.com/
 * 
 */


#include <PRIZM.h>      // include PRIZM library
#include <Pixy2I2C.h>   // include Pixy Cam I2C library
#define I2C

Pixy2I2C pixy;          // instantiate a name for pixy cam object
PRIZM prizm;            // instantiate a name for PRIZM object

void setup()
{
  prizm.PrizmBegin();   // initialize PRIZM. Wait for green start button press
  
  Serial.begin(9600);
  Serial.print("Starting...\n");

  pixy.init();
  // change to the line_tracking program.  Note, changeProg can use partial strings, so for example,
  // you can change to the line_tracking program by calling changeProg("line") instead of the whole
  // string changeProg("line_tracking")
  Serial.println(pixy.changeProg("line"));
}

void loop()
{
  int8_t i;
  char buf[128];
 
  pixy.line.getMainFeatures();

  if (pixy.line.numVectors)
    pixy.line.vectors->print();         // print detected line vector data
 
  if (pixy.line.numIntersections)       // print detected line intersection data
    pixy.line.intersections->print();

  if (pixy.line.barcodes)               // print barcode data
    pixy.line.barcodes->print();

}
